@@ -17,7 +17,7 @@ our @ISA = qw(Log::Log4perl::Appender);
 use IPC::Shareable qw(:lock);
 use IPC::Semaphore;
 
-our $CVSVERSION   = '$Revision: 1.4 $';
+our $CVSVERSION   = '$Revision: 1.6 $';
 our ($VERSION)    = ($CVSVERSION =~ /(\d+\.\d+)/);
 
 ###########################################
@@ -219,7 +219,7 @@ To control access to different appender instances, it often makes sense
 to define different keys for different synchronizing appenders. In this
 way, Log::Log4perl serializes access to each appender instance separately:
 
-    log4perl.category                   = WARN, Syncer
+    log4perl.category                   = WARN, Syncer1, Syncer2
     
         # File appender 1 (unsynchronized)
     log4perl.appender.Logfile1           = Log::Log4perl::Appender::File
@@ -253,7 +253,7 @@ passes them on to its attached sub-appender.
 For this reason, it doesn't need a layout (contrary to regular appenders).
 If it defines none, messages are passed on unaltered.
 
-Custom filters are also applied to the composite appender only
+Custom filters are also applied to the composite appender only.
 They are I<not> applied to the sub-appender. Same applies to appender
 thresholds. This behaviour might change in the future.
 
